@@ -1311,6 +1311,10 @@ _expectations = {
         test_winsound
         """,
 }
+_expectations['linux2-alpha'] = _expectations['linux2']
+_expectations['linux2-hppa'] = _expectations['linux2']
+_expectations['linux2-mips'] = _expectations['linux2']
+_expectations['linux2-sparc'] = _expectations['linux2']
 _expectations['freebsd5'] = _expectations['freebsd4']
 _expectations['freebsd6'] = _expectations['freebsd4']
 _expectations['freebsd7'] = _expectations['freebsd4']
