@@ -15,9 +15,10 @@ our @EXPORT = qw($version $progname $admindir $dpkglibdir $pkgdatadir);
 our ($progname) = $0 =~ m#(?:.*/)?([^/]*)#;
 
 # The following lines are automatically fixed at install time
-our $version="1.14.16.6ubuntu1";
+our $version="1.14.24ubuntu1";
 our $admindir="/var/lib/dpkg";
 our $dpkglibdir="/usr/lib/dpkg";
 our $pkgdatadir="/usr/share/dpkg";
+$pkgdatadir = $ENV{DPKG_DATADIR} if defined $ENV{DPKG_DATADIR};
 
 1;
